### scraper-hj3415

#### Introduction 


---
#### Requirements

scrapy>=2.11.2


---
#### API

1. nfscraper

2. miscraper

---
#### Install


---
#### Composition
새로운 scrapy 프로젝트를 만들 때는 프로젝트 가장 외부폴더명과 그 안쪽 폴더명이 달라야 한다. 
안그러면 setting파일을 찾을수 없다는 에러가 발생한다.
(ex - nfscrapy/nfs(프로젝트명은 nfs로 하고 외부 폴더명을 nfscrapy로 변경))

---

